@@ -1,12 +1,12 @@
-from django.conf import settings
 from django.contrib.gis.geos import LineString
 from django.utils.translation import gettext as _
-from geostore.serializers import LayerSerializer
+from geostore import settings as app_settings
+from geostore.serializers import LayerSerializer as BaseLayerSerializer
 from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
 from rest_framework_gis import serializers as geo_serializers
 
-from geostore_routing.serializers.mixins import RoutingLayerSerializer
+from geostore_routing.serializers.mixins import RoutingLayerSerializerMixin
 
 
 class RoutingSerializer(serializers.Serializer):
@@ -18,10 +18,9 @@ class RoutingSerializer(serializers.Serializer):
     def validate_geom(self, value):
         if not isinstance(value, LineString):
             raise ValidationError(_("Geometry should be a LineString object."))
-        if not value.srid:
-            value.srid = settings.INTERNAL_GEOMETRY_SRID
+        value.srid = app_settings.INTERNAL_GEOMETRY_SRID
         return value
 
 
-class RoutingLayerSerializer(RoutingLayerSerializer, LayerSerializer):
+class LayerSerializer(RoutingLayerSerializerMixin, BaseLayerSerializer):
     pass
