@@ -1,9 +1,9 @@
 import types
 
 from django.contrib.gis.geos import Point
+from django.utils.translation import gettext_lazy as _
 from rest_framework import status
 from rest_framework.decorators import action
-from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
 
 from ..helpers import Routing, RoutingException
@@ -12,8 +12,7 @@ from ..serializers import RoutingSerializer
 
 class RoutingViewsSetMixin:
     @action(detail=True, methods=['post'],
-            serializer_class=RoutingSerializer,
-            permission_classes=[IsAuthenticated])
+            serializer_class=RoutingSerializer)
     def route(self, request, pk=None):
         layer = self.get_object()
         data = request.data
@@ -27,10 +26,13 @@ class RoutingViewsSetMixin:
                 points = [Point(c, srid=geometry.srid) for c in geometry.coords]
                 routing = Routing(points, layer)
 
-                # if not route:
-                #     return Response(status=status.HTTP_204_NO_CONTENT)
+                if not routing.routes:
+                    data = {"message": _("Way not available"),
+                            "code": "NoRoute",
+                            "routes": []}
+                    return Response(data, status=response_status)
 
-                distance_1, distance_2, way = routing.get_linestring()
+                start_on_way, end_on_way, distance_1, distance_2, way = routing.get_linestring()
 
                 # generate response data by using serializer, to keep serialization rules (precision / perfs.)
                 response = types.SimpleNamespace()
@@ -42,9 +44,8 @@ class RoutingViewsSetMixin:
                 serializer.is_valid()
                 data = serializer.data
                 data['geom'] = request.data['geom']
-                data['waypoints'] = routing.full_waypoints
-                data['waypoints'][0]['distance'] = distance_1
-                data['waypoints'][-1]['distance'] = distance_2
+                data['waypoints'] = [{"coordinates": start_on_way.coords, "distance": distance_1},
+                                     {"coordinates": end_on_way.coords, "distance": distance_2}]
                 data['callback_id'] = request.data.get('callback_id', None)
 
             except RoutingException as exc:
